@@ -1,4 +1,3 @@
-import os
 import sys
 import time
 import json
@@ -9,8 +8,8 @@ import pandas as pd
 import datetime
 from os.path import join, split, exists
 from d3m_interface.basic_ta3 import BasicTA3
-from d3m_interface.visualization import plot_metadata, plot_comparison_pipelines
-from d3m_interface.data_converter import is_d3m_format, convert_d3m_format, copy_folder
+from d3m_interface.visualization import plot_metadata, plot_comparison_pipelines, plot_text_summary
+from d3m_interface.data_converter import is_d3m_format, convert_d3m_format, convert_d3mtext_dataframe, copy_folder
 from d3m.metadata.problem import PerformanceMetric
 from threading import Thread
 
@@ -119,7 +118,6 @@ class Automl:
             search_id = pipeline['search_id']
             pipeline['json_representation'] = pipeline_json
             pipeline['summary'] = summary_pipeline
-            pipeline['found_time'] = end_time.isoformat() + 'Z'
             duration = str(end_time - start_time)
             logger.info('Found pipeline id=%s, time=%s, scoring...' % (pipeline['id'], duration))
 
@@ -302,16 +300,20 @@ class Automl:
 
         return metric, score
 
-    def create_pipelineprofiler_inputs(self, test_dataset=None):
+    def create_pipelineprofiler_inputs(self, test_dataset=None, source_name=None):
         """Create an proper input supported by PipelineProfiler based on the pipelines generated by a TA2 system
 
         :param test_dataset: Path to dataset. If None it will use the search scores, otherwise will score the
             pipelines over the passed dataset
+        :param source_name: Name of the pipeline source. If None it will use the TA2 id
         :returns: List of pipelines in the PipelineProfiler input format
         """
         profiler_inputs = []
         pipeline_ids = set()
 
+        if source_name is None:
+            source_name = self.ta2_id
+
         if test_dataset is not None:
             logger.info('Calculating scores in the test dataset...')
 
@@ -324,8 +326,8 @@ class Automl:
                 pipeline_score = [{'metric': {'metric': pipeline['metric']}, 'value': pipeline['score'],
                                    'normalized': pipeline['normalized_score']}]
                 problem = self.dataset
-                start_time = pipeline['json_representation']['created']
-                end_time = pipeline['found_time']
+                start_time = pipeline['start_time']
+                end_time = pipeline['end_time']
 
                 if test_dataset is not None:
                     problem = test_dataset
@@ -350,7 +352,7 @@ class Automl:
                     'start': start_time,
                     'end': end_time,
                     'scores': pipeline_score,
-                    'pipeline_source': {'name': self.ta2_id},
+                    'pipeline_source': {'name': source_name},
                 }
                 profiler_inputs.append(profiler_data)
 
@@ -384,7 +386,6 @@ class Automl:
                 '-e', 'D3MSTATICDIR=/output',  # TODO: Temporal assignment for D3MSTATICDIR env variable
                 '-v', '%s:/input/dataset/' % self.dataset,
                 '-v', '%s:/output' % self.output_folder,
-                '--user', '%s:%s' % (os.geteuid(), os.getgid()),
                 TA2_DOCKER_IMAGES[self.ta2_id]
             ]
         )
@@ -405,9 +406,11 @@ class Automl:
     def score_in_search(self, pipeline, dataset_in_container, problem_path, pipelines, method, stratified, shuffle,
                         folds, train_ratio, random_seed):
         try:
+            pipeline['start_time'] = datetime.datetime.utcnow().isoformat() + 'Z'
             score_data = self.ta3.do_score(pipeline['id'], dataset_in_container, problem_path, method, stratified,
                                            shuffle, folds, train_ratio, random_seed)
             logger.info('Scored pipeline id=%s, %s=%s' % (pipeline['id'], score_data['metric'], score_data['score']))
+            pipeline['end_time'] = datetime.datetime.utcnow().isoformat() + 'Z'
             pipeline['score'] = score_data['score']
             pipeline['normalized_score'] = score_data['normalized_score']
             pipeline['metric'] = score_data['metric']
@@ -438,15 +441,26 @@ class Automl:
 
         plot_metadata(dataset_path)
 
-    def plot_comparison_pipelines(self, test_dataset=None):
+    def plot_comparison_pipelines(self, test_dataset=None, source_name=None):
         """ Plot PipelineProfiler visualization
 
         :param test_dataset: Path to dataset. If None it will use the search scores, otherwise will score the
             pipelines over the passed dataset
+        :param source_name: Name of the pipeline source. If None it will use the TA2 id
         """
-        pipelineprofiler_inputs = self.create_pipelineprofiler_inputs(test_dataset)
+        pipelineprofiler_inputs = self.create_pipelineprofiler_inputs(test_dataset, source_name)
         plot_comparison_pipelines(pipelineprofiler_inputs)
 
+    def plot_text_analysis(self, dataset_path, category_column, text_column):
+        """ Plot a visualization for text datasets
+
+        :param dataset_path: Path to dataset.  It supports D3M dataset
+        :param category_column: Name of the column that contains the categories
+        :param text_column: Name of the column that contains the texts
+        """
+        dataframe = convert_d3mtext_dataframe(dataset_path, text_column)
+        plot_text_summary(dataframe, category_column, text_column)
+
     @staticmethod
     def add_new_ta2(ta2_id, docker_image_url):
         """Add a new TA2 system that is not already defined in the D3M Interface. It can also be a different version of
