@@ -2,7 +2,8 @@ import os
 import json
 import shutil
 import logging
-from os.path import join, exists
+import pandas as pd
+from os.path import join, exists, split
 from d3m.container import Dataset
 from d3m.utils import fix_uri
 from d3m.container.utils import save_container
@@ -120,6 +121,20 @@ def create_d3m_problem(dataset, destination_path, problem_config):
         json.dump(problem_json, fout, indent=4)
 
 
+def convert_d3mtext_dataframe(folder_path, text_column):
+    suffix = split(folder_path)[1]
+    dataframe = pd.read_csv(join(folder_path, 'dataset_%s/tables/learningData.csv' % suffix))
+    folder_files = join(folder_path, 'dataset_%s/media/' % suffix)
+
+    for index, row in dataframe.iterrows():
+        file_path = join(folder_files, row[text_column])
+        with open(file_path, 'r') as fin:
+            text = fin.read().replace('\n', ' ')
+            dataframe.at[index, text_column] = text
+
+    return dataframe
+
+
 def copy_folder(source_path, destination_path):
     if exists(destination_path):
         shutil.rmtree(destination_path)
